
# Type: gene associated with condition


holds between a gene and a disease or phenotypic feature that the gene or its alleles/products may influence, contribute to, or correlate with

URI: [biolink:gene_associated_with_condition](https://w3id.org/biolink/vocab/gene_associated_with_condition)


## Domain and Range

[Gene](Gene.md) ->  <sub>0..*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [Gene](Gene.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WD:P2293 |
| **In Subsets:** | | translator_minimal |

